# Generated by Django 3.0 on 2020-07-04 09:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('microblog', '0002_add_weight'),
    ]

    operations = [
        migrations.AlterField(
            model_name='post',
            name='weight',
            field=models.IntegerField(blank=True, default=0, null=True, verbose_name='weight'),
        ),
    ]
